//----------------------------------------------------------------------------
// qimu.h : visualization widget for IMU device data
//
// 	- programmed by Boyoon Jung (boyoon@robotics.usc.edu)
//----------------------------------------------------------------------------
#ifndef __QIMU_H
#define __QIMU_H

// header files for IMU device
#include <imu.h>

// header files for Qt library
#include <q3dmg_ui.h>			// MicroStrain 3DM-G
#include <q3dmg_pose.h>

// header files for debugging
#include <iostream>
#include <cstdio>
#include <cerrno>
using std::cerr;
using std::endl;


// class definition for MicroStrain 3DM-G
class Q3dmg : public Q3dmgUI
{
    Q_OBJECT

    protected:
	MicroStrain3DMG* imu;		// MicroStrain 3DM-G IMU

	// over-written event handler
	virtual void timerEvent(QTimerEvent*);

	// update the pose estimation page
	void updatePose(void);
	
	// update the orientation page
	void updateOrientation(void);

	// update the vector page
	void updateVector(void);

	// update the voltage page
	void updateVoltage(void);

	// update the misc page
	void updateMisc(void);

    protected slots:
	// start/stop updating IMU information
	void updateSlot(int state);

	// capture gyroscope bias
	void captureSlot(void);

    public:
	// constructor
	Q3dmg(MicroStrain3DMG* imu=0, QWidget* parent=0, const char* name=0, WFlags f=0);
	// destructor
	~Q3dmg(void);

	// set/get the IMU
	void setIMU(MicroStrain3DMG* imu);
	MicroStrain3DMG* getIMU(void) { return imu; }
};

#endif	// __QIMU_H
